####
nsot
####

|Build Status| |Documentation Status|

Network Source of Truth (NSoT) a source of truth database and repository for
tracking inventory and metadata of network entities to ease management and
automation of network infrastructure.

NSoT is an API-first application that provides a REST API and a web application
front-end for managing IP addresses (IPAM), network devices, and network
interfaces.

Resources
=========

+ `Documentation <http://nsot.readthedocs.org/>`_
+ `Python API client/CLI utility <http://pynsot.readthedocs.org/>`_
+ IRC: ``#nsot`` on ``irc.freenode.net``

.. |Build Status| image:: https://travis-ci.org/dropbox/nsot.png?branch=master
   :target: https://travis-ci.org/dropbox/nsot
.. |Documentation Status| image:: https://readthedocs.org/projects/nsot/badge/?version=latest
   :target: https://readthedocs.org/projects/nsot/?badge=latest
